==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/ISheetAccess.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package org.xlsx4j.sml;

public interface ISheetAccess {

    public CTDrawing getDrawing();

    public void setDrawing(CTDrawing value);

    public CTLegacyDrawing getLegacyDrawing();

    public void setLegacyDrawing(CTLegacyDrawing value);
    
    public CTLegacyDrawing getLegacyDrawingHF();
    
    public void setLegacyDrawingHF(CTLegacyDrawing value);

    public CTDrawingHF getDrawingHF();

    public void setDrawingHF(CTDrawingHF value);

    public CTPageMargins getPageMargins();

    public void setPageMargins(CTPageMargins value);
    
    public CTHeaderFooter getHeaderFooter();

    public void setHeaderFooter(CTHeaderFooter value);

    public CTSheetBackgroundPicture getPicture();

    public void setPicture(CTSheetBackgroundPicture value);

    public CTWebPublishItems getWebPublishItems();

    public void setWebPublishItems(CTWebPublishItems value);

    public CTExtensionList getExtLst(boolean forceCreate);

    public void setExtLst(CTExtensionList value);
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/ISheetAccess.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package org.xlsx4j.sml;

public interface ISheetAccess {

    public CTDrawing getDrawing();

    public void setDrawing(CTDrawing value);

    public CTLegacyDrawing getLegacyDrawing(boolean forceCreate);

    public void setLegacyDrawing(CTLegacyDrawing value);
    
    public CTLegacyDrawing getLegacyDrawingHF();
    
    public void setLegacyDrawingHF(CTLegacyDrawing value);

    public CTDrawingHF getDrawingHF();

    public void setDrawingHF(CTDrawingHF value);

    public CTPageMargins getPageMargins();

    public void setPageMargins(CTPageMargins value);
    
    public CTHeaderFooter getHeaderFooter();

    public void setHeaderFooter(CTHeaderFooter value);

    public CTSheetBackgroundPicture getPicture();

    public void setPicture(CTSheetBackgroundPicture value);

    public CTWebPublishItems getWebPublishItems();

    public void setWebPublishItems(CTWebPublishItems value);

    public CTExtensionList getExtLst(boolean forceCreate);

    public void setExtLst(CTExtensionList value);
}
